package Ledger::Examples;

our $DATE = '2015-03-26'; # DATE
our $VERSION = '0.02'; # VERSION

1;
# ABSTRACT: Example Ledger files

__END__

=pod

=encoding UTF-8

=head1 NAME

Ledger::Examples - Example Ledger files

=head1 VERSION

This document describes version 0.02 of Ledger::Examples (from Perl distribution Ledger-Examples), released on 2015-03-26.

=head1 DESCRIPTION

This distribution contains various examples of valid and invalid Ledger journal
files in its per-dist share dir.

=head1 SEE ALSO

L<Ledger::Parser>

L<http://www.ledger-cli.org>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Ledger-Examples>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Ledger-Examples>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Ledger-Examples>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
